flutter_embed_unity library

Classes

EmbedUnity
Embed Unity into your Flutter app and listen for messages from your Unity scripts.
EmbedUnityPreferences

Functions

pauseUnity() → void
Pause time in Unity.
resumeUnity() → void
Resume time in Unity.
sendToUnity(String gameObjectName, String methodName, String data) → void
Send data to a public MonoBehaviour method named methodName attached to a Unity game object named gameObjectName in the active scene.